#! /bin/bash

VERSION=0.10.16

cp -v ../deb/stimfit_${VERSION}-1.debian.tar.gz /media/webftp/StimfitJ/deb/
cp -v ../deb/stimfit_${VERSION}-1.dsc /media/webftp/StimfitJ/deb/
cp -v ../deb/stimfit_${VERSION}.orig.tar.gz /media/webftp/StimfitJ/deb/
